

set -ex



pushd libs/python/example/tutorial
export CONDA_BUILD_SYSROOT=/opt/MacOSX10.10.sdk
export CONDA_BUILD=1
bjam -q -d+2 --debug --debug-configuration
python -c 'from __future__ import print_function; import hello_ext; print(hello_ext.greet())'
popd
test -f $PREFIX/include/boost/python.hpp
test -d $PREFIX/include/boost/python
test -f $PREFIX/lib/libboost_python.a
test -f $PREFIX/lib/libboost_python36.a
test -f $PREFIX/lib/libboost_python.dylib
test -f $PREFIX/lib/libboost_python36.dylib
test -f $PREFIX/lib/libboost_numpy.a
test -f $PREFIX/lib/libboost_numpy36.a
test -f $PREFIX/lib/libboost_numpy.dylib
test -f $PREFIX/lib/libboost_numpy36.dylib
exit 0
